@@ -42,12 +42,3 @@ drop_na..data.frame <- function(.df, ...) {
     na.omit(.df, cols = drop_cols)
   }
 }
-
-#' @export
-#' @rdname dt_verb
-#' @inheritParams drop_na.
-dt_drop_na <- function(.df, ...) {
-  deprecate_stop("0.5.2", "tidytable::dt_drop_na()", "drop_na.()")
-
-  drop_na.(.df, ...)
-}
