@@ -1,7 +1,7 @@
 #' Return row number
 #'
 #' @description
-#' This function is designed to work inside of `mutate.()`
+#' Returns row number. This function is designed to work inside of `mutate.()`
 #'
 #' @md
 #' @export
@@ -12,6 +12,5 @@
 #' test_df %>%
 #'   mutate.(row = row_number.())
 row_number. <- function() {
-  eval_tidy(expr(1:.N), env = caller_env())
+  eval_expr(1:.N, env = caller_env())
 }
-
