@@ -11,9 +11,6 @@
 #' @importFrom utils capture.output head packageName tail type.convert
 NULL
 
-globalVariables(c(".", "name", "value", "..select_cols",
-                  "..keep_names", "..unite_cols", "..keep_cols", ".env", ".id", "where"))
-
 #' @docType import
 
 ## Reexports ------------------------
