@@ -1,5 +1,3 @@
-setup(options(lifecycle_verbosity = "quiet"))
-
 test_that("empty count.() returns number of rows", {
   test_df <- data.table(a = 1:3, b = 4:6, c = c("a", "a", "a"), d = c("a", "a", "b"))
   summary_df <- test_df %>%
@@ -9,15 +7,6 @@ test_that("empty count.() returns number of rows", {
   expect_equal(summary_df$N, nrow(test_df))
 })
 
-test_that("empty dt_count() returns number of rows", {
-  test_df <- data.table(a = 1:3, b = 4:6, c = c("a", "a", "a"), d = c("a", "a", "b"))
-  summary_df <- test_df %>%
-    dt_count()
-
-  expect_named(summary_df, c("N"))
-  expect_equal(summary_df$N, nrow(test_df))
-})
-
 test_that("count.() works on data.frame", {
   test_df <- data.frame(a = 1:3, b = 4:6, c = c("a", "a", "a"), d = c("a", "a", "b"))
   summary_df <- test_df %>%
