@@ -1,4 +1,4 @@
-test_that("distinct.() works on all rows", {
+test_that("works on all rows", {
   test_df <- tidytable(a = rep(1, 3), b = rep(2, 3), c = c("a", "a", "b"))
   distinct_df <- test_df %>%
     distinct.()
@@ -7,7 +7,7 @@ test_that("distinct.() works on all rows", {
   expect_equal(distinct_df$c, c("a", "b"))
 })
 
-test_that("distinct.() works on a data.frame", {
+test_that("works on a data.frame", {
   test_df <- data.frame(a = 1:3, b = 4:6, c = c("a", "a", "b"))
   distinct_df <- test_df %>%
     distinct.()
@@ -16,16 +16,34 @@ test_that("distinct.() works on a data.frame", {
   expect_equal(as_tidytable(test_df), distinct_df)
 })
 
-test_that("distinct.() works on 1 column", {
-  test_df <- data.table(a = 1:3, b = 4:6, c = c("a", "a", "b"), d = c("a", "a", "b"))
+test_that("works on 1 column", {
+  test_df <- data.table(a = 1:3, b = c(4,4,5), c = c("a", "a", "b"), d = c("a", "a", "b"))
   distinct_df <- test_df %>%
     distinct.(b)
 
   expect_named(distinct_df, c("b"))
-  expect_equal(test_df$b, 4:6)
+  expect_equal(distinct_df$b, c(4, 5))
 })
 
-test_that("distinct.() works with enhanced selection", {
+test_that("works on 1 column and can utilize renaming", {
+  test_df <- data.table(a = rep(1, 3), b = rep(2, 3), c = c("a", "a", "b"), d = c("a", "a", "b"))
+  distinct_df <- test_df %>%
+    distinct.(stuff = b)
+
+  expect_named(distinct_df, c("stuff"))
+  expect_equal(distinct_df$stuff, c(2))
+})
+
+test_that("works on 1 column and can utilize renaming with .keep_all = TRUE", {
+  test_df <- data.table(a = rep(1, 3), b = rep(2, 3), c = c("a", "a", "b"), d = c("a", "a", "b"))
+  distinct_df <- test_df %>%
+    distinct.(stuff = b, .keep_all = TRUE)
+
+  expect_named(distinct_df, c("a", "stuff", "c", "d"))
+  expect_equal(distinct_df$stuff, c(2))
+})
+
+test_that("works with enhanced selection", {
   test_df <- data.table(a = 1:3, b = 4:6, c = c("a", "a", "b"), d = c("a", "a", "b"))
   distinct_df <- test_df %>%
     distinct.(where(is.character))
